@@ -6,17 +6,12 @@ function(y,k)
     m <- mean(y)
     vr1 <- sum( (y-m)^2 )/n
 
-    index <- 1:k
-    summ <- 0
-
-    for (i in k:n)
-    {
-    summ <- summ + (sum(y[index]) -k*m)^2
-    index <- index+1
-    }
+    # use the filter function
+    flt = filter(y, rep(1,k), method = "convolution")
+    flt = flt[!is.na(flt)]
+    summ = sum((flt - k * m)^2)
 
     vr2 <- summ/(n*k)
     vr <- vr2/vr1 -1
  return(vr)
  }
-
